define(["dojo/_base/declare",
        "dijit/layout/ContentPane", 
        "dijit/_TemplatedMixin",
    	"dijit/_WidgetsInTemplateMixin",
    	"dijit/form/Button",
		"dijit/registry",
		"dojo/_base/lang",
		"dojo/_base/array",
		"./UpdatePane",
    	"dojo/text!./templates/SearchPane.html"],

function (declare, ContentPane, _TemplatedMixin, _WidgetsInTemplateMixin, Button, registry, lang, array, UpdatePane, template){
	
	return declare([ContentPane, _TemplatedMixin, _WidgetsInTemplateMixin],
	{
		templateString: template,
		widgetsInTemplate: true,
		
		csTree: null,
		updatePane: null,
		
		
		constructor: function (args) {
		 	this.searchTitle = i18nUI.searchTitle;
			this.searchEMReports = i18nUI.searchEMReports;
			this.clear = i18nUI.clear;
	    },
	    
	    startup: function () {
	    	this.inherited(arguments);
	    	this._init();
	    	this._createActions();
	    },
	     
	    _init: function() {
	    	
			var initTreeCallback = {
					onSuccess:  dojo.hitch(this, function(csTree){
				
						this.csTree = csTree;
				     	this.csTree.startup();		    	
					})			 
				};
	         bisProvider.getContentAsTree(initTreeCallback, "ContentTree", null);
 			 
	    },
		
		_search: function (items, index) {
		
			var searchButton = registry.byId("searchButton");
			if(index>=items.length){
				// end searching
				this.updatePane.refreshSearchResults();
				searchButton.set("disabled", false);
				return;
			} 
			var searchCallback = {						
				onSuccess: dojo.hitch(this, function(data){	
					log(data.length + " results on " + items[index].identifier);
					// add search results
					this.updatePane.addSearchResults(data);
					// search for next selected folder or report		
					this._search(items, ++index);
				}),
				onFailure: dojo.hitch(this, function(error){
					log("Error on " + items[index].identifier + ": " + error);
					this._search(items, ++index);
				})
			};
		
			log("Searching EM4C reports on: " + items[index].identifier);
			bisProvider.search4EMReports(searchCallback, [items[index]]);
		},
		
		_createActions: function () {
			var searchButton = registry.byId("searchButton");

			searchButton.on("click",  
				lang.hitch(this, function() {
				   
					var items = this.csTree.getCheckedItems();
					if(items.length > 0) {				
						// start searching
						searchButton.set("disabled", true);
						
						if(this.updatePane==null){
							this.updatePane = new UpdatePane({}).placeAt(dojo.byId("center"));						
							this.updatePane.startup();
						}
						this.updatePane.clearSearchResults();
						this._search(items, 0);
					}
			}));	
			
			registry.byId("clearButton").on("click",  
				lang.hitch(this, function() {
					log("clear all selected");
					this.csTree.unCheckAll();
			}));	
		}
	});
});